<?php return array(
    'root' => array(
        'name' => '__root__',
        'pretty_version' => 'dev-main',
        'version' => 'dev-main',
        'reference' => '454256c81c69dee8734d52bda30ea66e4915208c',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => true,
    ),
    'versions' => array(
        '__root__' => array(
            'pretty_version' => 'dev-main',
            'version' => 'dev-main',
            'reference' => '454256c81c69dee8734d52bda30ea66e4915208c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ergebnis/phpstan-rules' => array(
            'pretty_version' => '2.13.1',
            'version' => '2.13.1.0',
            'reference' => 'f69db86b98595c34fc1f61c89fe3b380141aa519',
            'type' => 'phpstan-extension',
            'install_path' => __DIR__ . '/../ergebnis/phpstan-rules',
            'aliases' => array(),
            'dev_requirement' => true,
        ),
        'nette/utils' => array(
            'pretty_version' => 'v4.1.3',
            'version' => '4.1.3.0',
            'reference' => 'bb3ea637e3d131d72acc033cfc2746ee893349fe',
            'type' => 'library',
            'install_path' => __DIR__ . '/../nette/utils',
            'aliases' => array(),
            'dev_requirement' => true,
        ),
        'phpstan/extension-installer' => array(
            'pretty_version' => '1.4.3',
            'version' => '1.4.3.0',
            'reference' => '85e90b3942d06b2326fba0403ec24fe912372936',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../phpstan/extension-installer',
            'aliases' => array(),
            'dev_requirement' => true,
        ),
        'phpstan/phpstan' => array(
            'pretty_version' => '2.1.42',
            'version' => '2.1.42.0',
            'reference' => '1279e1ce86ba768f0780c9d889852b4e02ff40d0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phpstan/phpstan',
            'aliases' => array(),
            'dev_requirement' => true,
        ),
        'phpstan/phpstan-strict-rules' => array(
            'pretty_version' => '2.0.10',
            'version' => '2.0.10.0',
            'reference' => '1aba28b697c1e3b6bbec8a1725f8b11b6d3e5a5f',
            'type' => 'phpstan-extension',
            'install_path' => __DIR__ . '/../phpstan/phpstan-strict-rules',
            'aliases' => array(),
            'dev_requirement' => true,
        ),
        'tomasvotruba/type-coverage' => array(
            'pretty_version' => '2.1.0',
            'version' => '2.1.0.0',
            'reference' => '468354b3964120806a69890cbeb3fcf005876391',
            'type' => 'phpstan-extension',
            'install_path' => __DIR__ . '/../tomasvotruba/type-coverage',
            'aliases' => array(),
            'dev_requirement' => true,
        ),
    ),
);
